#
# This script was written by Renaud Deraison <deraison@cvs.nessus.org>,
#
#
# See the Nessus Scripts License for details
#

if(description)
{
 script_id(11267);
 name["english"] = "OpenSSL password interception";

 script_name(english:name["english"]);
 
 desc["english"] = "
The remote host is using a version of OpenSSL which is
older than 0.9.6i or 0.9.7a

This version is vulnerable to a timing based attack which may
allow an attacker to guess the content of fixed data blocks
(such as passwords or credit card number).

An attacker may use this implementation flaw to sniff the
data going to this host and decrypt some parts of it.

*** Nessus solely relied on the banner of the remote host
*** to issue this warning

See also : http://www.openssl.org/news/secadv_20030219.txt
	   http://lasecwww.epfl.ch/memo_ssl.shtml

Solution : Upgrade to version 0.9.6i (0.9.7a) or newer
Risk factor : Medium";

 script_description(english:desc["english"], francais:desc["francais"]);
 
 summary["english"] = "Checks for version of OpenSSL";
 summary["francais"] = "Ve'rifie la version de OpenSSL";
 
 script_summary(english:summary["english"], francais:summary["francais"]);
 
 script_category(ACT_GATHER_INFO);
 
 
 script_copyright(english:"This script is Copyright (C) 2003 Renaud Deraison",
		francais:"Ce script est Copyright (C) 2003 Renaud Deraison");
 family["english"] = "Misc.";
 family["francais"] = "Divers";
 script_family(english:family["english"], francais:family["francais"]);
 script_dependencie("find_service.nes");
 script_require_ports("Services/www", 80);
 exit(0);
}

#
# The script code starts here - we rely on Apache to spit OpenSSL's
# version. That suck.
#

port = get_kb_item("Services/www");
if(!port)port = 443;
if(get_port_state(port))
{
 key = string("www/banner/", port);
 banner = get_kb_item(key);
 if(!banner)
 {
   soc = open_sock_tcp(port);
   req = http_get(item:"/", port:port);
   send(socket:soc, data:req);
   banner = recv(socket:soc, length:2000);
   close(soc);
 }
 
 

 serv = strstr(banner, "Server");
 
 if(ereg(pattern:".*OpenSSL/0\.9\.([0-5][^0-9]|6[a-h]).*", string:serv))
 {
   security_warning(port);
   exit(0);
 }
 
 if(ereg(pattern:".*OpenSSL/0\.9\.7-beta.*", string:serv))
 {
  security_warning(port);
  exit(0);
 }
}
